# Contributing to Robyn-Rate-Limits
Thanks for deciding to contribute!
The following guidelines exists so contribution is easy and transparent, so we kindly request that you follow it.

## General rules
- Be nice and respectful
- For any and all contributions, make sure an issue exists before submitting any pull request.
- When creating new issues, describe the issue clearly and add as much detail as possible.
- Issues will be assigned on a "first come, first served" basis.
- Commit message should follow the [Conventional Commits](https://www.conventionalcommits.org/) style.

## We use [Github Flow](https://docs.github.com/en/get-started/quickstart/github-flow), so all changes happen through pull requests
We actively welcome your pull requests:

1. Fork the repo and create your branch from `main`.
2. If you've added code that should be tested, add tests.
3. If you've changed APIs, update the documentation.
4. Ensure the test suite passes.
5. Run pre-commit hooks to lint and format your changes.

## Report bugs using Github's [issues](https://github.com/IdoKendo/robyn_rate_limits/issues)
We use GitHub issues to track bugs. Report a bug by [opening a new issue](https://github.com/IdoKendo/robyn_rate_limits/issues/new); it's that easy!

## Write bug reports with detail, background, and sample code
**Great Bug Reports** tend to have:

- A quick summary and/or background
- Steps to reproduce
  - Be specific!
  - Give sample code if you can.
- What was expected to happen
- What actually happens

## License
By contributing, you agree that your contributions will be licensed under its MIT License.
